@@ -221,19 +221,6 @@ book_backend_kolab_notify_opened (EBookBackendKolab *self,
 	return TRUE;
 }
 
-static void
-book_backend_kolab_notify_removed (EBookBackendKolab *self)
-{
-	EBookBackend *bbackend = NULL;
-
-	g_assert (E_IS_BOOK_BACKEND_KOLAB (self));
-
-	bbackend = E_BOOK_BACKEND (self);
-
-	e_book_backend_notify_readonly (bbackend, TRUE);
-	e_book_backend_notify_online (bbackend, FALSE);
-}
-
 /*----------------------------------------------------------------------------*/
 /* class functions */
 
@@ -352,39 +339,6 @@ book_backend_kolab_open (EBookBackendSync *backend,
 	}
 }
 
-static void
-book_backend_kolab_remove (EBookBackendSync *backend,
-                           EDataBook *book,
-                           GCancellable *cancellable,
-                           GError **error)
-{
-	EBookBackendKolab *self = NULL;
-	EBookBackendKolabPrivate *priv = NULL;
-	GError *tmp_err = NULL;
-	gboolean ok = FALSE;
-
-	g_return_if_fail (error == NULL || *error == NULL);
-	e_return_data_book_error_if_fail (E_IS_BOOK_BACKEND_KOLAB (backend), E_DATA_BOOK_STATUS_INVALID_ARG);
-	e_return_data_book_error_if_fail (E_IS_DATA_BOOK (book), E_DATA_BOOK_STATUS_INVALID_ARG);
-	/* cancellable may be NULL */
-
-	self = E_BOOK_BACKEND_KOLAB (backend);
-	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
-
-	if (priv->book_koma != NULL) {
-		ok = kolab_mail_access_shutdown (priv->book_koma,
-		                                 cancellable,
-		                                 &tmp_err);
-		if (ok) {
-			g_object_unref (priv->book_koma);
-			priv->book_koma = NULL;
-			book_backend_kolab_notify_removed (self);
-		} else {
-			g_propagate_error (error, tmp_err);
-		}
-	}
-}
-
 static void
 book_backend_kolab_refresh (EBookBackendSync *backend,
                             EDataBook *book,
@@ -924,11 +878,12 @@ book_backend_kolab_authenticate_user (EBookBackendSync *backend,
 #endif
 
 static void
-book_backend_kolab_start_book_view (EBookBackend *backend,
-                                    EDataBookView *book_view)
+book_backend_kolab_start_view (EBookBackend *backend,
+                               EDataBookView *book_view)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
+	EBookBackendSExp *sexp;
 	GList *econtact_list = NULL;
 	GList *it = NULL;
 	const gchar *query = NULL;
@@ -953,7 +908,8 @@ book_backend_kolab_start_book_view (EBookBackend *backend,
 		goto exit;
 	}
 
-	query = e_data_book_view_get_card_query (book_view);
+	sexp = e_data_book_view_get_sexp (book_view);
+	query = e_book_backend_sexp_text (sexp);
 	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	/* try to switch into online mode. if that fails,
@@ -1039,8 +995,8 @@ book_backend_kolab_start_book_view (EBookBackend *backend,
 }
 
 static void
-book_backend_kolab_stop_book_view (EBookBackend *backend,
-                                   EDataBookView *book_view)
+book_backend_kolab_stop_view (EBookBackend *backend,
+                              EDataBookView *book_view)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND_KOLAB (backend));
 	g_return_if_fail (E_IS_DATA_BOOK_VIEW (book_view));
@@ -1117,12 +1073,11 @@ e_book_backend_kolab_class_init (EBookBackendKolabClass *klass)
 	object_class->finalize = e_book_backend_kolab_finalize;
 
 	/* Backend parent class methods methods not covered in the sync backend part */
-	backend_class->start_book_view = book_backend_kolab_start_book_view;
-	backend_class->stop_book_view = book_backend_kolab_stop_book_view;
+	backend_class->start_view = book_backend_kolab_start_view;
+	backend_class->stop_view = book_backend_kolab_stop_view;
 
 	/* Sync backend class functions */
 	sync_class->open_sync = book_backend_kolab_open;
-	sync_class->remove_sync = book_backend_kolab_remove;
 	sync_class->refresh_sync = book_backend_kolab_refresh;
 	sync_class->get_backend_property_sync = book_backend_kolab_get_backend_property;
 	sync_class->create_contacts_sync = book_backend_kolab_create_contacts;
