@@ -34,6 +34,30 @@
 /*----------------------------------------------------------------------------*/
 /* internal statics */
 
+static ESource*
+util_calendar_ref_top_source (ESourceRegistry *registry,
+                              ESource *source)
+{
+	ESource *top_source = NULL;
+	gchar *top_uid = NULL;
+
+	g_return_val_if_fail (E_IS_SOURCE_REGISTRY (registry), NULL);
+	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
+
+	top_source = g_object_ref (source);
+	while (TRUE) {
+		top_uid = e_source_dup_parent (top_source);
+		if (top_uid == NULL)
+			break;
+		g_object_unref (top_source);
+		top_source = e_source_registry_ref_source (registry,
+		                                           top_uid);
+		g_free (top_uid);
+	}
+
+	return top_source;
+}
+
 static KolabUtilHttpJob*
 util_calendar_create_http_request (KolabSettingsHandler *ksettings,
                                    const gchar *path,
@@ -60,7 +84,7 @@ util_calendar_create_http_request (KolabSettingsHandler *ksettings,
 	 * default ports for this protocol type will be used
 	 */
 	camel_url_set_port (url, 0);
-	
+
 	passwd = kolab_settings_handler_get_char_field (ksettings,
 	                                                KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD,
 	                                                &tmp_err);
@@ -101,7 +125,7 @@ util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
 	network_settings = CAMEL_NETWORK_SETTINGS (camel_settings);
 	username = camel_network_settings_get_user (network_settings);
 
-	if (strncmp (username, "INBOX/", 6))
+	if (strncmp (sourcename, "INBOX/", 6) == 0)
 		source_offset = 6;
 	path = g_strdup_printf ("/freebusy/trigger/%s/%s.pfb",
 	                        username, sourcename+source_offset);
@@ -120,6 +144,7 @@ util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
 static KolabUtilHttpJob*
 util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
                                   gchar *query,
+                                  gboolean extended,
                                   GError **error)
 {
 	KolabUtilHttpJob *job = NULL;
@@ -130,24 +155,148 @@ util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
 	g_assert (query != NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	path = g_strdup_printf ("/freebusy/%s.ifb", query);
+	if (extended)
+		path = g_strdup_printf ("/freebusy/%s.xfb", query);
+	else
+		path = g_strdup_printf ("/freebusy/%s.ifb", query);
 
 	job = util_calendar_create_http_request (ksettings,
 	                                         path,
 	                                         &tmp_err);
 	g_free (path);
+
 	if (tmp_err != NULL) {
 		g_propagate_error (error, tmp_err);
-		g_warning ("%s()[%u] call to kolab_util_calendar_create_http_request() returned NULL!",
-		           __func__, __LINE__);
 		return NULL;
 	}
+
 	return job;
 } /* util_calendar_create_xfb_request () */
 
+static KolabUtilHttpJob*
+util_calendar_retrieve_xfb (KolabSettingsHandler *ksettings,
+                            gchar *query,
+                            gboolean extended,
+                            GError **error)
+{
+	KolabUtilHttpJob *job = NULL;
+	GError *tmp_err = NULL;
+
+	g_assert (KOLAB_IS_SETTINGS_HANDLER (ksettings));
+	g_assert (query != NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	job = util_calendar_create_xfb_request (ksettings,
+	                                        query,
+	                                        extended,
+	                                        &tmp_err);
+	if (job == NULL)
+		goto exit;
+
+	job->buffer = g_byte_array_new ();
+	(void) kolab_util_http_get (job, &tmp_err);
+
+ exit:
+
+	if (tmp_err != NULL) {
+		g_propagate_error (error, tmp_err);
+		if (job != NULL) {
+			kolab_util_http_job_free (job);
+			job = NULL;
+		}
+	}
+
+	return job;
+} /* util_calendar_retrieve_xfb */
+
 /*----------------------------------------------------------------------------*/
 /* public API */
 
+/**
+ * kolab_util_calendar_dup_email_address:
+ * @backend: the cal backend via which we get to the source registry
+ *
+ * Retrieves the email address associated with the @backend
+ * from the source registry. The caller needs to free the
+ * result, if non-NULL.
+ *
+ * Returns: An email address or NULL if none found.
+ * Since: 3.6
+ */
+gchar*
+kolab_util_calendar_dup_email_address (ECalBackend *backend)
+{
+	ESourceRegistry *registry = NULL;
+	ESourceMailIdentity *extension = NULL;
+	ESource *esource = NULL;
+	ESource *top_source = NULL;
+	GList *sources = NULL;
+	GList *sources_ptr = NULL;
+	gchar *mail_addr = NULL;
+	gchar *my_top_uid = NULL;
+	const gchar *top_uid = NULL;
+
+	g_return_val_if_fail (E_IS_CAL_BACKEND (backend), NULL);
+
+	registry = e_cal_backend_get_registry (backend);
+	g_return_val_if_fail (E_IS_SOURCE_REGISTRY (registry), NULL);
+
+	esource = e_backend_get_source (E_BACKEND (backend));
+	top_source = util_calendar_ref_top_source (registry, esource);
+	my_top_uid = e_source_dup_uid (top_source);
+	g_object_unref (top_source);
+	g_return_val_if_fail (my_top_uid != NULL, NULL);
+
+	sources = e_source_registry_list_sources (registry,
+	                                          E_SOURCE_EXTENSION_MAIL_IDENTITY);
+	sources_ptr = sources;
+	while (sources_ptr != NULL) {
+		esource = E_SOURCE (sources_ptr->data);
+		if (esource == NULL) {
+			/* should not normally happen */
+			g_warning ("%s()[%u] Got NULL ESource, skipping",
+			           __func__, __LINE__);
+			goto source_skip;
+		}
+
+		top_source = util_calendar_ref_top_source (registry,
+		                                           esource);
+		if (top_source == NULL) {
+			/* should not normally happen */
+			g_warning ("%s()[%u] Got NULL top ESource, skipping",
+			           __func__, __LINE__);
+			goto source_skip;
+		}
+
+		top_uid = e_source_get_uid (top_source);
+		g_object_unref (top_source);
+
+		if (g_strcmp0 (my_top_uid, top_uid) == 0) {
+			/* be sure the esource has the mail identity extension */
+			if (! e_source_has_extension (esource, E_SOURCE_EXTENSION_MAIL_IDENTITY)) {
+				g_warning ("%s()[%u] ESource %s has no mail identity extension, skipping.",
+				           __func__, __LINE__, e_source_get_uid (esource));
+				goto source_skip;
+			}
+			extension = e_source_get_extension (esource,
+			                                    E_SOURCE_EXTENSION_MAIL_IDENTITY);
+			mail_addr = e_source_mail_identity_dup_address (extension);
+		}
+
+		if (mail_addr != NULL)
+			break;
+
+	source_skip:
+
+		sources_ptr = g_list_next (sources_ptr);
+	}
+
+	if (sources != NULL)
+		g_list_free_full (sources, g_object_unref);
+
+	return mail_addr;
+}
+
 /**
  * kolab_util_calendar_get_tzid:
  * @comp: An ECalComponent to derive the tzid from.
@@ -245,24 +394,29 @@ kolab_util_calendar_retrieve_xfb (KolabSettingsHandler *ksettings,
 	g_assert (query != NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	job = util_calendar_create_xfb_request (ksettings,
-	                                        (gchar *) query,
-	                                        &tmp_err);
-	if (job == NULL) {
-		g_propagate_error (error, tmp_err);
-		g_warning ("%s()[%u] error creating job, giving up on %s.",
-		           __func__, __LINE__, (gchar *) query);
-		return NULL;
+	job = util_calendar_retrieve_xfb (ksettings,
+	                                  query,
+	                                  TRUE, /* try XFB */
+	                                  &tmp_err);
+	if (job != NULL)
+		goto done;
+
+	if (tmp_err != NULL) {
+		g_warning ("%s()[%u] %s",
+		           __func__, __LINE__, tmp_err->message);
+		g_error_free (tmp_err);
+		tmp_err = NULL;
 	}
 
-	job->buffer = g_byte_array_new ();
-	(void)kolab_util_http_get (job, &tmp_err);
-	if (tmp_err != NULL) {
-		/* might happen, perhaps the server did not know about the user. */
-		kolab_util_http_job_free (job);
+	job = util_calendar_retrieve_xfb (ksettings,
+	                                  query,
+	                                  FALSE, /* try SFB */
+	                                  &tmp_err);
+
+	if (tmp_err != NULL)
 		g_propagate_error (error, tmp_err);
-		return NULL;
-	}
+
+ done:
 
 	return job;
 } /* kolab_util_calendar_retrieve_xfb () */
