@@ -23,6 +23,7 @@
 #include <libekolab/camel-kolab-imapx-settings.h>
 
 #include <libekolabutil/kolab-util-camel.h>
+#include <libekolabutil/kolab-util.h>
 
 #define E_KOLAB_BACKEND_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -34,9 +35,6 @@
 #define REGISTER_TYPE(type) \
 	(g_type_class_unref (g_type_class_ref (type)))
 
-#define KOLAB_PATH_SEPARATOR   '/'
-#define KOLAB_PATH_SEPARATOR_S "/"
-
 struct _EKolabBackendPrivate {
 	KolabMailAccess *koma;
 	GMutex koma_lock;
@@ -486,7 +484,8 @@ e_kolab_backend_ref_mail_access_sync (EKolabBackend *backend,
 	settings = kolab_backend_get_settings (backend);
 	source = e_backend_get_source (E_BACKEND (backend));
 
-	settings_handler = kolab_settings_handler_new (settings);
+	settings_handler = kolab_settings_handler_new (settings,
+	                                               E_BACKEND (backend));
 
 	/* XXX Christian recommends KOLAB_FOLDER_CONTEXT_EMAIL here
 	 *     although the operations we need are supposed to work
@@ -503,20 +502,10 @@ e_kolab_backend_ref_mail_access_sync (EKolabBackend *backend,
 		return NULL;
 	}
 
-	/* This must be done after configure() and bringup(). */
-	success = kolab_settings_handler_set_char_field (
-		settings_handler,
-		KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID,
-		e_source_dup_uid (source), error);
-	if (!success) {
-		g_object_unref (settings_handler);
-		return NULL;
-	}
-
 	koma = g_object_new (KOLAB_TYPE_MAIL_ACCESS, NULL);
 
 	success = kolab_mail_access_configure (
-		koma, E_BACKEND (backend), settings_handler, error);
+		koma, settings_handler, error);
 	if (!success) {
 		g_object_unref (settings_handler);
 		g_object_unref (koma);
