@@ -22,7 +22,7 @@
 #include <config.h>
 #include <glib/gi18n-lib.h>
 
-#include <misc/e-port-entry.h>
+#include <e-util/e-util.h>
 
 #include <mail/e-mail-config-auth-check.h>
 #include <mail/e-mail-config-service-page.h>
