@@ -145,12 +145,12 @@ camel_kolab_imapx_settings_init (CamelKolabIMAPXSettings *self)
 CamelURL *
 camel_kolab_imapx_settings_build_url (CamelKolabIMAPXSettings *settings)
 {
-	CamelURL *url;
-	CamelNetworkSettings *network_settings;
+	CamelURL *url = NULL;
+	CamelNetworkSettings *network_settings = NULL;
 	CamelNetworkSecurityMethod method;
-	const gchar *host;
-	const gchar *user;
-	guint16 port;
+	const gchar *host = NULL;
+	const gchar *user = NULL;
+	guint16 port = 0;
 
 	g_return_val_if_fail (CAMEL_IS_KOLAB_IMAPX_SETTINGS (settings), NULL);
 
