@@ -35,6 +35,7 @@
 #include <libekolabutil/kolab-util-glib.h>
 #include <libekolabutil/kolab-util-error.h>
 #include <libekolabutil/kolab-util-camel.h>
+#include <libekolabutil/kolab-util.h>
 
 #include "camel-kolab-session.h"
 #include "camel-kolab-imapx-store.h"
@@ -678,7 +679,7 @@ mail_imap_client_query_foldernames (KolabMailImapClient *self,
 	} else {
 		folder_list = kolab_util_camel_folderlist_from_folderinfo (fi);
 	}
-	
+
 	camel_store_free_folder_info (CAMEL_STORE (priv->store), fi);
 
 	return folder_list;
@@ -756,13 +757,14 @@ mail_imap_client_store (KolabMailImapClient *self,
 		/* split foldername into parent_name and folder_name
 		 * (we get full path here)
 		 */
-		path = kolab_util_camel_imap_path_split (foldername, "/"); /* FIXME get delimiter from store */
+		path = kolab_util_camel_imap_path_split (foldername,
+		                                         KOLAB_PATH_SEPARATOR_S); /* FIXME get delimiter from store */
 		if (path == NULL) {
 			g_warning ("%s()[%u]: KolabUtilCamelIMAPPath instance for path '%s' is NULL. This should never happen.",
 			           __func__, __LINE__, foldername);
 			goto cleanup;
 		}
-		
+
 		fi = camel_store_create_folder_sync (CAMEL_STORE (priv->store),
 		                                     path->parent_name,
 		                                     path->folder_name,
@@ -788,10 +790,10 @@ mail_imap_client_store (KolabMailImapClient *self,
 			           __func__, __LINE__);
 			ok = TRUE;
 		}
-		
+
 		if (tmp_err != NULL)
 			goto cleanup;
-		
+
 		goto cleanup;
 	}
 
@@ -1033,19 +1035,18 @@ mail_imap_client_store (KolabMailImapClient *self,
 
 gboolean
 kolab_mail_imap_client_configure (KolabMailImapClient *self,
-                                  EBackend *backend,
                                   KolabSettingsHandler *ksettings,
                                   KolabMailMimeBuilder *mimebuilder,
                                   GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
+	EBackend *backend = NULL;
 	/* const gchar *tmp_str = NULL; */
 	const gchar *data_dir = NULL;
 	const gchar *cache_dir = NULL;
 	GError *tmp_err = NULL;
 
 	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
-	g_assert (E_IS_BACKEND (backend));
 	g_assert (KOLAB_IS_SETTINGS_HANDLER (ksettings));
 	g_assert (KOLAB_IS_MAIL_MIME_BUILDER (mimebuilder));
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
@@ -1100,6 +1101,7 @@ kolab_mail_imap_client_configure (KolabMailImapClient *self,
 	}
 
 	/* create session object */
+	backend = kolab_settings_handler_get_e_backend (priv->ksettings);
 	priv->session = camel_kolab_session_new (backend, data_dir, cache_dir);
 
 	/* set to offline state first */
@@ -1404,7 +1406,7 @@ kolab_mail_imap_client_get_password (KolabMailImapClient *self)
 {
 	KolabMailImapClientPrivate *priv = NULL;
 	const gchar *passwd = NULL;
-	
+
 	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
 
 	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
@@ -1416,7 +1418,7 @@ kolab_mail_imap_client_get_password (KolabMailImapClient *self)
 	 * Camel for the (X)FB triggers only, which are not sent unless
 	 * we went online, so no trouble to be expected here.
 	 */
-	
+
 	g_return_val_if_fail (priv->store != NULL, NULL);
 	passwd = camel_service_get_password (CAMEL_SERVICE (priv->store));
 
@@ -1540,7 +1542,7 @@ kolab_mail_imap_client_query_folder_info_online (KolabMailImapClient *self,
 				g_warning ("%s()[%u]: NULL folder descriptor for folder '%s', type '%u'",
 				           __func__, __LINE__, foldername, type_id);
 		}
-		
+
 		folder_names_ptr = g_list_next (folder_names_ptr);
 	}
 
@@ -1738,13 +1740,13 @@ kolab_mail_imap_client_delete_folder (KolabMailImapClient *self,
 
 	if (has_children)
 		goto folder_skip;
-	
+
 	folder = camel_store_get_folder_sync (CAMEL_STORE (priv->store),
 	                                      foldername,
 	                                      0,
 	                                      cancellable,
 	                                      &tmp_err);
-	
+
 	if (tmp_err != NULL)
 		goto exit;
 
@@ -1757,7 +1759,7 @@ kolab_mail_imap_client_delete_folder (KolabMailImapClient *self,
 	has_messages = (camel_folder_get_message_count (folder) > 0);
 
  folder_skip:
-	
+
 	/* won't delete a folder which has subfolders or messages in it */
 	if (has_children || has_messages) {
 		g_set_error (&tmp_err,
@@ -1784,7 +1786,7 @@ kolab_mail_imap_client_delete_folder (KolabMailImapClient *self,
 
 	if (folder)
 		g_object_unref (folder);
-	
+
 	return ok;
 }
 
