@@ -381,7 +381,7 @@ kolab_mail_mime_builder_conv_new_from_camel (KolabMailMimeBuilder *self,
 }
 
 static CamelMimePart*
-kolab_mail_mime_builder_new_zeroth_mime_part (KolabMailMimeBuilder *self)
+mail_mime_builder_new_zeroth_mime_part (KolabMailMimeBuilder *self)
 {
 	KolabMailMimeBuilderPrivate *priv = NULL;
 	CamelMimePart *zeroth_part = NULL;
@@ -436,7 +436,7 @@ kolab_mail_mime_builder_camel_new_from_conv (KolabMailMimeBuilder *self,
 		return NULL;
 
 	/* create new zeroth part */
-	zeroth_part = kolab_mail_mime_builder_new_zeroth_mime_part (self);
+	zeroth_part = mail_mime_builder_new_zeroth_mime_part (self);
 
 	/* create multipart, add zeroth part */
 	multipart = camel_multipart_new ();
