@@ -1849,7 +1849,6 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 	KolabFolderContextID folder_context = KOLAB_FOLDER_CONTEXT_INVAL;
 	KolabObjectCacheStatus status = KOLAB_OBJECT_CACHE_STATUS_INVAL;
 	KolabObjectCacheStatus new_status = KOLAB_OBJECT_CACHE_STATUS_INVAL;
-	gconstpointer sync_id_ptr = NULL;
 	GHashTable *changed_uids_tbl = NULL;
 	GList *changed_uids_lst = NULL;
 	gchar *uid = NULL;
@@ -1938,10 +1937,9 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		goto cleanup;
 	}
 
-	sync_id_ptr = kolab_settings_handler_get_value (priv->ksettings,
-	                                                KOLAB_SETTINGS_HANDLER_TBL_SYNCSTRATEGY,
-	                                                foldername,
-	                                                &tmp_err);
+	sync_id = kolab_settings_handler_get_uint_field (priv->ksettings,
+	                                                 KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_SYNCSTRATEGY,
+	                                                 &tmp_err);
 	if (tmp_err != NULL) {
 		sync_id = KOLAB_SYNC_STRATEGY_DEFAULT;
 		g_warning ("%s: %s", __func__, tmp_err->message);
@@ -1949,8 +1947,6 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		         __func__, sync_id);
 		g_error_free (tmp_err);
 		tmp_err = NULL;
-	} else {
-		sync_id = GPOINTER_TO_UINT (sync_id_ptr);
 	}
 	g_debug ("%s: UID (%s) Folder (%s) sync strategy id (%u)",
 	         __func__, uid, foldername, sync_id);
