@@ -37,9 +37,9 @@ typedef enum {
 	KOLAB_TLS_VARIANT_NONE = 0,
 	KOLAB_TLS_VARIANT_SSL,
 	KOLAB_TLS_VARIANT_STARTTLS,
-	KOLAB_TLS_LAST_VARIANT,
-	KOLAB_TLS_FIRST_VARIANT = KOLAB_TLS_VARIANT_NONE,
-	KOLAB_TLS_VARIANT_DEFAULT = KOLAB_TLS_VARIANT_STARTTLS
+	KOLAB_TLS_LAST_VARIANT,                                   /*< skip >*/
+	KOLAB_TLS_FIRST_VARIANT = KOLAB_TLS_VARIANT_NONE,         /*< skip >*/
+	KOLAB_TLS_VARIANT_DEFAULT = KOLAB_TLS_VARIANT_STARTTLS    /*< skip >*/
 } KolabTLSVariantID;
 
 #define KOLAB_TLS_DESC_VARIANT_NONE "No encryption"
@@ -47,6 +47,7 @@ typedef enum {
 #define KOLAB_TLS_DESC_VARIANT_TLS  "TLS encryption"
 
 #define KOLAB_TLS_VARIANT_PROP "kolab-encryption-method"
+#define KOLAB_PORT_NUMBER_PROP "kolab-port-number"
 
 /* PIM data conflict resolution variants */
 typedef enum {
@@ -54,9 +55,9 @@ typedef enum {
 	KOLAB_SYNC_STRATEGY_SERVER,	/* always use server data set	*/
 	KOLAB_SYNC_STRATEGY_CLIENT,	/* always use client data set	*/
 	KOLAB_SYNC_STRATEGY_DUPE,	/* create duplicate (new UID)	*/
-	KOLAB_SYNC_LAST_STRATEGY,
-	KOLAB_SYNC_FIRST_STRATEGY = KOLAB_SYNC_STRATEGY_NEWEST,
-	KOLAB_SYNC_STRATEGY_DEFAULT = KOLAB_SYNC_STRATEGY_NEWEST
+	KOLAB_SYNC_LAST_STRATEGY,                                 /*< skip >*/
+	KOLAB_SYNC_FIRST_STRATEGY = KOLAB_SYNC_STRATEGY_NEWEST,   /*< skip >*/
+	KOLAB_SYNC_STRATEGY_DEFAULT = KOLAB_SYNC_STRATEGY_NEWEST  /*< skip >*/
 } KolabSyncStrategyID;
 
 #define KOLAB_STRATEGY_DESC_NEWEST "Take Newer (last modified)"
@@ -64,14 +65,12 @@ typedef enum {
 #define KOLAB_STRATEGY_DESC_CLIENT "Take Local (client-side)"
 #define KOLAB_STRATEGY_DESC_DUPE   "Take Both (resulting in two different, parallel entries)"
 
-#define KOLAB_SYNC_STRATEGY_PROP "kolab-sync-strategy"
-
 typedef enum {
 	KOLAB_PKCS11_INFRASTRUCTURE_DISABLE,
 	KOLAB_PKCS11_INFRASTRUCTURE_ENABLE,
-	KOLAB_PKCS11_INFRASTRUCTURE_LAST,
-	KOLAB_PKCS11_INFRASTRUCTURE_FIRST = KOLAB_PKCS11_INFRASTRUCTURE_DISABLE,
-	KOLAB_PKCS11_INFRASTRUCTURE_DEFAULT = KOLAB_PKCS11_INFRASTRUCTURE_DISABLE
+	KOLAB_PKCS11_INFRASTRUCTURE_LAST,                                          /*< skip >*/
+	KOLAB_PKCS11_INFRASTRUCTURE_FIRST = KOLAB_PKCS11_INFRASTRUCTURE_DISABLE,   /*< skip >*/
+	KOLAB_PKCS11_INFRASTRUCTURE_DEFAULT = KOLAB_PKCS11_INFRASTRUCTURE_DISABLE  /*< skip >*/
 } KolabReqPkcs11;
 
 #define KOLAB_REQ_PKCS11_PROP	"kolab-require-pkcs11-infrastructure"
