@@ -60,7 +60,9 @@
 
 #include "camel-kolab-stream.h"
 #include "camel-system-headers.h"
+
 #include "kolab-util-http.h"
+#include "kolab-util.h"
 
 /*----------------------------------------------------------------------------*/
 
@@ -142,10 +144,13 @@ util_http_curl_writefunc (const void *data,
 }
 
 static CURLcode
-util_http_curl_set_genopts (void)
+util_http_curl_set_genopts (const gchar *user_home)
 {
-	/* TODO change this to table-based for-loop */
 	CURLcode curlcode; /* can't bit-or this... */
+	gchar *capath = NULL;
+
+	/* user_home may be NULL */
+
 	curlcode =  curl_easy_setopt (kolab_curl_handle,
 	                              CURLOPT_VERBOSE,
 	                              KOLAB_UTIL_HTTP_CURL_DEBUG);
@@ -174,6 +179,7 @@ util_http_curl_set_genopts (void)
 	                             CURLOPT_FOLLOWLOCATION,
 	                             KOLAB_UTIL_HTTP_CURL_FOLLOW_REDIRECTS);
 	if (curlcode) return curlcode;
+
 	/* SSL setup
 	 * The following may fail if NSS is not yet initialized
 	 */
@@ -186,6 +192,23 @@ util_http_curl_set_genopts (void)
 	                             KOLAB_UTIL_HTTP_CURL_SSL_VERIFY_HOST);
 	if (curlcode) return curlcode;
 
+	/* set the CAPATH to the nssdb (works for NSS only,
+	 * which we depend upon)
+	 */
+	if (user_home == NULL)
+		goto capath_skip;
+
+	capath = g_build_path (KOLAB_PATH_SEPARATOR_S,
+	                       user_home,
+	                       KOLAB_UTIL_HTTP_CURL_NSS_CERTDB,
+	                       NULL);
+	curlcode = curl_easy_setopt (kolab_curl_handle,
+	                             CURLOPT_CAPATH,
+	                             capath);
+	g_free (capath);
+
+ capath_skip:
+
 	/* TODO more here
 	 * - HTTP options (referrers, encoding, follow, user-agent...)
 	 */
@@ -278,8 +301,9 @@ util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 		g_set_error (error,
 		             KOLAB_UTIL_HTTP_ERROR,
 		             KOLAB_UTIL_HTTP_ERROR_CONFIGURATION_ERROR,
-		             _("Configuring libcurl failed with CURLcode: %u"),
-		             curlcode);
+		             _("Configuring libcurl failed with CURLcode: %u (%s)"),
+		             curlcode,
+		             curl_easy_strerror (curlcode));
 		return -1;
 	}
 
@@ -300,10 +324,10 @@ util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 		g_set_error (error,
 		             KOLAB_UTIL_HTTP_ERROR,
 		             error_code,
-		             _("Access to URL '%s' failed in libcurl with CURLcode: %u"),
-		             camel_url_to_string (job->url, CAMEL_URL_HIDE_AUTH), curlcode);
-	}
-	else {
+		             _("Access to URL '%s' failed in libcurl with CURLcode: %u (%s)"),
+		             camel_url_to_string (job->url, CAMEL_URL_HIDE_AUTH),
+		             curlcode, curl_easy_strerror (curlcode));
+	} else {
 		nbytes = (gssize)job->buffer->len;
 	}
 
@@ -312,6 +336,9 @@ util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 	 *      if so, also increment nbytes
 	 */
 
+	if (nbytes > -1)
+		job->nbytes = nbytes;
+
 	return nbytes;
 }
 
@@ -319,6 +346,7 @@ util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 
 /**
  * kolab_util_http_init:
+ * @user_home: path to the user's home directory
  *
  * Initializes the HTTP subsystem. This means
  * <itemizedlist>
@@ -330,11 +358,13 @@ util_http_curl_get (KolabUtilHttpJob *job, GError **error)
  * functions.
  */
 void
-kolab_util_http_init (void)
+kolab_util_http_init (const gchar *user_home)
 {
 	glong curl_global_flags;
 	static gboolean http_is_initialized = FALSE;
 
+	/* user_home may be NULL */
+
 	if (http_is_initialized == TRUE)
 		return;
 
@@ -350,7 +380,7 @@ kolab_util_http_init (void)
 
 	kolab_curl_handle = curl_easy_init ();
 	g_assert (kolab_curl_handle != NULL);
-	util_http_curl_set_genopts ();
+	util_http_curl_set_genopts (user_home);
 	http_is_initialized = TRUE;
 }
 
